#include "canvaswidget.h"

#include <QAction>
#include <QFileDialog>
#include "TList.h"

CanvasWidget::CanvasWidget(QWidget *parent)
  : TQtWidget(parent)
{
  setContextMenuPolicy(Qt::ActionsContextMenu);
  
  QAction *actSave = new QAction("Save As", this);
  connect(actSave, SIGNAL(triggered()), SLOT(SaveAs()));
  addAction(actSave);
}

void CanvasWidget::HideObject(TObject *o)
{
  if (fCanvas->FindObject(o)) {
    fCanvas->GetListOfPrimitives()->Remove(o);
    Refresh();
  }
}

void CanvasWidget::SaveAs()
{
  QString fileName = 
    QFileDialog::getSaveFileName(this, "Save As ...",
				 QDir::currentPath(),
				 tr("PostScript (*.ps)\n"
				    "Encapsulated PostScript (*.eps)\n"
				    "PDF (*.pdf)\n"
				    "SVG (*.svg)\n"
				    "GIF (*.gif)\n"
				    "ROOT macros (*.C)\n"
				    "XML (*.xml)\n"
				    "PNG (*.png)\n"
				    "XPM (*.xpm)\n"
				    "JPEG (*.jpg)\n"
				    "TIFF (*.tiff)\n"
				    "XCF (*.xcf)\n"
				    "All files (*.*)"));
  if (fileName.isEmpty())
    return;
  
  fCanvas->Print(fileName.toAscii());
}

void CanvasWidget::mouseMoveEvent(QMouseEvent *e)
{
	/// Disable TQtWidget::mouseMoveEvent() to prevent ROOT changing cursor shape.
	QWidget::mouseMoveEvent(e);
}

void CanvasWidget::mouseReleaseEvent(QMouseEvent *e)
{
	if ((e->button() == Qt::LeftButton))
		emit MouseClicked(e->pos());

	QWidget::mouseMoveEvent(e);
}
